@@ -5,7 +5,7 @@ use File::ShareDir qw/dist_dir/;
 use Path::Tiny;
 use DBIx::ThinSQL::Deploy;
 
-our $VERSION = '0.0.16';
+our $VERSION = '0.0.17_1';
 
 sub _doit {
     my $self = shift;
@@ -61,14 +61,13 @@ sub DBIx::ThinSQL::db::drop_views {
 
 sub DBIx::ThinSQL::db::drop_everything {
     my $self = shift;
-    return
-         _doit( $self, 'indexes' )
-      && _doit( $self, 'functions' )
-      && _doit( $self, 'languages' )
-      && _doit( $self, 'sequences' )
-      && _doit( $self, 'tables' )
-      && _doit( $self, 'triggers' )
-      && _doit( $self, 'views' );
+    return _doit( $self, 'indexes' ) +
+      _doit( $self, 'functions' ) +
+      _doit( $self, 'languages' ) +
+      _doit( $self, 'sequences' ) +
+      _doit( $self, 'tables' ) +
+      _doit( $self, 'triggers' ) +
+      _doit( $self, 'views' );
 }
 
 1;
